##
##  redis-mod-search.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2022 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_opkg 2.2.6
%define       V_dist 2.2.6

#   package information
Name:         redis-mod-search
Summary:      Redis Extension Module: Full-Text Search (FTS)
URL:          http://redisearch.io/
Vendor:       Redis Community
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Database
License:      RSAL
Version:      %{V_opkg}
Release:      20220110

#   list of sources
Source0:      https://github.com/RedisLabsModules/RediSearch/archive/v%{V_dist}.tar.gz
Patch0:       redis-mod-search.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101
PreReq:       OpenPKG, openpkg >= 20160101
PreReq:       redis

%description
    This is a Redis extension module that implements Full-Text Searching.

%track
    prog redis-mod-search = {
        version   = %{V_dist}
        url       = https://github.com/RedisLabsModules/RediSearch/releases
        regex     = v(\d+\.\d+\.\d+)\.tar\.gz
    }

%prep
    %setup -q -n RediSearch-%{V_dist}
    %patch -p0

%build
    #   build extension module
    cmake \
        -Wno-dev \
        -DCMAKE_BUILD_TYPE="Release" \
        -DCMAKE_C_COMPILER="%{l_cc}" \
        -DCMAKE_C_FLAGS="%{l_cflags -O}" \
        -DCMAKE_CXX_COMPILER="%{l_cxx}" \
        -DCMAKE_CXX_FLAGS="%{l_cxxflags -O}" \
        -DCMAKE_EXE_LINKER_FLAGS="%{l_ldflags}" \
        -DCMAKE_INSTALL_PREFIX="%{l_prefix}" \
        -DRS_FORCE_NO_GITVERSION=on \
        .
    %{l_make} %{l_mflags -O}

%install
    #   create installation hierarchy
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/libexec/redis

    #   install extension module
    %{l_shtool} install -c -m 755 \
        redisearch.so $RPM_BUILD_ROOT%{l_prefix}/libexec/redis/search.so

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

%post
    if [ ".$1" = .1 ]; then
        #   add hook to Redis configuration
        redisconf="$RPM_INSTALL_PREFIX/etc/redis/redis.conf"
        if [ -f $redisconf ]; then
            echo "loadmodule $RPM_INSTALL_PREFIX/libexec/redis/search.so" |\
            $RPM_INSTALL_PREFIX/lib/openpkg/rpmtool config \
                -a -i "$RPM_INSTALL_PREFIX:redis-mod-search" -p "#" $redisconf
        fi
    fi

%postun
    if [ ".$1" = .0 ]; then
        #   remove hook from Redis configuration
        redisconf="$RPM_INSTALL_PREFIX/etc/redis/redis.conf"
        if [ -f $redisconf ]; then
            $RPM_INSTALL_PREFIX/lib/openpkg/rpmtool config \
                -r -i "$RPM_INSTALL_PREFIX:redis-mod-search" -p "#" $redisconf
        fi
    fi

